#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: distributive
version: 0.5.0.2
id: distributive-0.5.0.2-6c580c91b8bf5de803bfa850eb262f37
key: distr_6isb974VoNY4WXj77jknOo
license: BSD3
copyright: Copyright (C) 2011-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/distributive/
synopsis: Distributive functors -- Dual to Traversable
description:
    Distributive functors -- Dual to Traversable
category: Data Structures
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Distributive Data.Distributive.Generic
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/distributive-0.5.0.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/distributive-0.5.0.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/distributive-0.5.0.2
hs-libraries: HSdistributive-0.5.0.2-6isb974VoNY4WXj77jknOo
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base-orphans-0.5.3-27215a9428d23686c8514fbd3bba8ccb
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
haddock-interfaces: /usr/share/doc/haskell-distributive/html/distributive.haddock
haddock-html: /usr/share/doc/haskell-distributive/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
